FlutterAlignmentConverter class

Inheritance
Annotations

Constructors

FlutterAlignmentConverter()

Properties

deriveFuture → Type
no setterinherited
deriveFutureOr → Type
no setterinherited
deriveIterable → Type
no setterinherited
deriveList → Type
no setterinherited
deriveSet → Type
no setterinherited
deriveStream → Type
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAssociated → bool
If the converter is associated with the type T. Used by the DogEngine.registerAutomatic to determine if a converter should be automatically registered to T.
finalinherited
isNullable → bool
no setterinherited
keepIterables → bool
If the converter should keep iterables as iterables or convert them automatically if they occur inside a DogStructure.
finalinherited
modes → Map<Type, OperationMode<Alignment> Function()>
Returns a map of Types to OperationMode factories.
no setterinherited
nullable → TypeCapture
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
struct → DogStructure<Alignment>?
The DogStructure associated with this converter and the type T.
finalinherited
typeArgument → Type
no setterinherited

Methods

castIterable(Iterable<Alignment> iterable) → Iterable<Alignment>
inherited
castList(List list) → List<Alignment>
inherited
castSet(Set set) → Set<Alignment>
inherited
consumeType<RETURN>(RETURN func<_>()) → RETURN
inherited
consumeTypeArg<RETURN, ARG>(RETURN func<_>(ARG), ARG arg) → RETURN
inherited
describeOutput(DogEngine engine, SchemaConfig config) → SchemaType
Generates a SchemaType describing the output generated by this converter.
override
deserialize(dynamic value, DogEngine engine) → Alignment
Deserializes the given value from a DogNativeCodec native value.
override
isAssignable(dynamic object) → bool
inherited
Links this instance to the given engine.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveOperationMode(DogEngine engine, Type opmodeType) → OperationMode<Alignment>?
Returns the operation mode for the given opmodeType or null if the converter does not support the given operation mode by default.
inherited
serialize(Alignment value, DogEngine engine) → dynamic
Serializes the given value to a DogNativeCodec native value.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited