NestedStructureAutoFactory class

Inheritance

Properties

deriveFuture → Type
no setterinherited
deriveFutureOr → Type
no setterinherited
deriveIterable → Type
no setterinherited
deriveList → Type
no setterinherited
deriveSet → Type
no setterinherited
deriveStream → Type
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isNullable → bool
no setterinherited
nullable → TypeCapture
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeArgument → Type
no setterinherited

Methods

castIterable(Iterable<FlutterWidgetBinder> iterable) → Iterable<FlutterWidgetBinder>
inherited
castList(List list) → List<FlutterWidgetBinder>
inherited
castSet(Set set) → Set<FlutterWidgetBinder>
inherited
consumeType<RETURN>(RETURN func<_>()) → RETURN
inherited
consumeTypeArg<RETURN, ARG>(RETURN func<_>(ARG), ARG arg) → RETURN
inherited
forConverter(DogConverter converter, DogEngine engine) → FlutterWidgetBinder?
Creates a new instance of T for the given converter and engine. See OperationModeCacheEntry.forConverter for details.
override
insert(OperationModeFactory<FlutterWidgetBinder> insertion, ModeFactoryInsertionSlot slot) → OperationModeFactory<FlutterWidgetBinder>
Composes this factory with another insertion factory, placing insertion in the specified slot.
inherited
isAssignable(dynamic object) → bool
inherited
Links this instance to the given engine.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited