FieldBindingParent class abstract interface

Implementers

Properties

engine → DogEngine
The dogs engine instance associated with this binding parent.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

field(String name) → FieldBindingController
Gets the binding controller for a specific field.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyFieldValue(String fieldName, dynamic fieldValue) → void
Notifies the controller of a field value change.
requestFieldValidation(String fieldName, dynamic fieldValue) → void
Requests validation for a specific field. The result of the validation will be pushed to the field's ValueNotifier.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited