classErrorListenable property
A notifier that holds all currently reported class errors.
Implementation
final ValueNotifier<AnnotationResult> classErrorListenable = ValueNotifier(
AnnotationResult.empty(),
);
A notifier that holds all currently reported class errors.
final ValueNotifier<AnnotationResult> classErrorListenable = ValueNotifier(
AnnotationResult.empty(),
);