StructureViewer<T> class

Constructors

StructureViewer(DogEngine engine, DogStructure structure)

Properties

engine → DogEngine
final
factories ↔ List<FlutterWidgetBinder>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structure → DogStructure
final

Methods

buildHeaderRow() → Iterable<Widget>
buildRow(T value) → Iterable<Widget>
fieldAt(T value, int index) → Widget
fieldNamed(T value, String name) → Widget
headerAt(int index) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create<T>({DogEngine? engine}) → StructureViewer<T>