ListBindingStyle class

Inheritance
Implemented types

Constructors

ListBindingStyle({String? addButtonLabel, double? spacing, ListBindingViewFactory? viewFactory, String? itemLabel})
const

Properties

addButtonLabel → String?
final
hashCode → int
The hash code for this object.
no setterinherited
itemLabel → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double?
final
viewFactory → ListBindingViewFactory?
final

Methods

createStyleOverrides() → BindingStyle
override
merge(ListBindingStyle? other) → ListBindingStyle
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited