MaterialBindingStyle class

Inheritance
Implemented types

Properties

buttonStyle → ButtonStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
inputTheme → InputDecorationThemeData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionTheme → InputDecorationThemeData?
final

Methods

createStyleOverrides() → BindingStyle
override
merge(MaterialBindingStyle? other) → MaterialBindingStyle
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited