BindingStyle class

Implemented types
Mixed-in types
Available extensions
Annotations

Constructors

BindingStyle({String? label, String? hint, String? helper, Widget? prefix, Widget? suffix, List<BindingStyleExtension> extensions = const []})
const

Properties

copy → BindingStyle$Copy

Available on BindingStyle, provided by the BindingStyleDogsExtension extension

no setter
extensions → List<BindingStyleExtension>
final
hashCode → int
The hash code for this object.
no setterinherited
helper → String?
final
hint → String?
final
label → String?
final
prefix → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → Widget?
final

Methods

asAncestor() → BindingStyle
buildInputSection(Widget widget, BuildContext context, {Object? labelOverride = #none, String? errorText}) → Widget

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

buildMaterialDecoration(BuildContext context, FieldBindingController fbc, {bool includeLabel = true, bool includeHelper = true, bool includeHint = true}) → InputDecoration

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

buildMaterialErrorText(BuildContext context, String? error) → Widget?

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

buildMaterialHelperOrErrorText(BuildContext context, String? error) → Widget?

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

buildMaterialHelperText(BuildContext context) → Widget?

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

buildMaterialLabelText(BuildContext context, {Object? labelOverride = #none, bool isError = false}) → Widget?

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

createStyleOverrides() → BindingStyle
override
getExtension<T extends BindingStyleExtension>() → T?
getMaterialButtonStyle() → ButtonStyle?

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

getTextFieldStyle() → TextFieldStyle

Available on BindingStyle, provided by the TextFieldStyleExtension extension

Gets the TextFieldStyle extension or returns a default one if not found
merge(BindingStyle? other) → BindingStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic f(BindingStyleBuilder b)) → BindingStyle

Available on BindingStyle, provided by the BindingStyleDogsExtension extension

resolveTheme(BuildContext context) → (InputDecorationThemeData, MaterialBindingStyle, ThemeData)

Available on BindingStyle, provided by the BindingStyleDataMaterialExtension extension

toBuilder() → BindingStyleBuilder

Available on BindingStyle, provided by the BindingStyleDogsExtension extension

toNative() → Map<String, dynamic>

Available on BindingStyle, provided by the BindingStyleDogsExtension extension

toString() → String
A string representation of this object.
inherited
visitSchemaField(SchemaField field) → void
Visit the given SchemaField instance.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

mergeExtensions(dynamic a, dynamic b) → List<BindingStyleExtension>