TextFieldStyle class

A style extension for TextField properties that are commonly modified. This extension is not tied to Material Design and can be used with any theme.

Inheritance
Implemented types

Constructors

TextFieldStyle({bool? obscureText, TextInputType? keyboardType, int? maxLines, int? minLines, int? maxLength, TextAlign? textAlign, TextStyle? textStyle, TextCapitalization? textCapitalization, bool? enabled, bool? readOnly, bool? autofocus, List<TextInputFormatter>? inputFormatters})
const

Properties

autofocus → bool?
Whether the text field should be focused initially.
final
enabled → bool?
Whether the text field is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
Optional input validation and formatting.
final
keyboardType → TextInputType?
The type of keyboard to use for editing the text.
final
maxLength → int?
The maximum number of characters (Unicode scalar values) to allow in the text field.
final
maxLines → int?
The maximum number of lines for the text to span.
final
minLines → int?
The minimum number of lines for the text to span.
final
obscureText → bool?
Whether to hide the text being edited (like for passwords).
final
readOnly → bool?
Whether the text field is read-only.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign?
How the text should be aligned horizontally.
final
textCapitalization → TextCapitalization?
The capitalization behavior for the keyboard.
final
textStyle → TextStyle?
The style to use for the text being edited.
final

Methods

createStyleOverrides() → BindingStyle
override
merge(TextFieldStyle? other) → TextFieldStyle
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited