BindingsErrorBuffer class

Constructors

BindingsErrorBuffer(DogStructure structure, IsolatedClassValidator classValidator, VoidCallback onChanged)

Properties

classErrors ↔ AnnotationResult
getter/setter pair
fieldErrors ↔ Map<String, AnnotationResult>
latefinal
hasErrors ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onChanged → VoidCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAll() → void
clearCustom() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(int index, AnnotationResult result) → void
putAll(List<AnnotationResult?> results) → void
putCustom(AnnotationResult result) → void
recalculateFieldErrors() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited