DatabindRequiredGuard class

Inheritance
Implemented types

Constructors

DatabindRequiredGuard()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

annotate(dynamic cached, dynamic value, DogEngine engine) → AnnotationResult
Annotates value with this validator returning an AnnotationResult. This mechanic is used to provide more information about the validation error.
override
getCachedValue(DogStructureField field) → dynamic
Returns a cached value for this validator. Will be passed to validate on every validation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(dynamic cached, dynamic value, DogEngine engine) → bool
Validates value against this validator.
override
verifyUsage(DogStructureField field) → void
Verifies the usage of this validator in field.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

sharedMessage → AnnotationMessage
final

Constants

messageId → const String