id property
Identifier for the type of the message, like "missing-field". Multiple messages in a result set may have the same id.
Implementation
final String id;
Identifier for the type of the message, like "missing-field". Multiple messages in a result set may have the same id.
final String id;