target property

String? target
final

Defines where the message is targeted at. This must confront to a field name of the referenced structure or may be null if not applicable to any individual field or if applicable to the whole structure.

Implementation

final String? target;