hasErrors property
bool
get
hasErrors
Returns true if this result contains any error messages.
Implementation
bool get hasErrors => messages.isNotEmpty;
Returns true if this result contains any error messages.
bool get hasErrors => messages.isNotEmpty;