withTarget method
Replaces the target of all messages in this result with target.
Implementation
AnnotationResult withTarget(String target) {
return AnnotationResult(messages: messages.map((e) => e.withTarget(target)).toList());
}
Replaces the target of all messages in this result with target.
AnnotationResult withTarget(String target) {
return AnnotationResult(messages: messages.map((e) => e.withTarget(target)).toList());
}