OperationMode<T> class abstract interface

An operation mode exposed by a DogConverter.

Operation modes are used to provide a specific functionality to a DogConverter, for example, a NativeSerializerMode provides a way to serialize and deserialize a value to a dart map while a ValidationMode provides a way to validate a value.

Implemented types
Implementers

Properties

deriveFuture Type
no setterinherited
deriveFutureOr Type
no setterinherited
deriveIterable Type
no setterinherited
deriveList Type
no setterinherited
deriveSet Type
no setterinherited
deriveStream Type
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNullable bool
no setterinherited
nullable TypeCapture
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeArgument Type
no setterinherited

Methods

castIterable(Iterable<T> iterable) Iterable<T>
inherited
castList(List list) List<T>
inherited
castSet(Set set) Set<T>
inherited
consumeType<RETURN>(RETURN func<_>()) → RETURN
inherited
consumeTypeArg<RETURN, ARG>(RETURN func<_>(ARG), ARG arg) → RETURN
inherited
initialise(DogEngine engine) → void
Initialises the operation mode with the given engine. This allows for the operation mode to possibly precache some data that would need to be lookup on every invocation otherwise.
isAssignable(dynamic object) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited