map static method

SchemaType map(
  1. SchemaType itemType
)

Creates a schema type representing a string-keyed map with values of the given item type.

Implementation

static SchemaType map(SchemaType itemType) {
  if (itemType is SchemaArray || itemType is SchemaMap) {
    log(
        "Multidimensional arrays and maps are not fully supported yet. "
        "While serialization should generally work, validation and container "
        "specific configurations may not work as expected.",
        level: 500);
  }

  return SchemaMap(itemType);
}