reference static method
Creates a schema type representing a reference to another schema by its serial name.
Implementation
static SchemaType reference(String serialName) => SchemaReference(serialName);
Creates a schema type representing a reference to another schema by its serial name.
static SchemaType reference(String serialName) => SchemaReference(serialName);