SyntheticTypeCapture class final

Inheritance
Mixed-in types
Available extensions

Constructors

SyntheticTypeCapture(String identity, {List<TypeTree> arguments = const []})
const

Properties

arguments → List<TypeTree>
final
base → TypeCapture
no setteroverride
deriveFuture → Type
no setterinherited
deriveFutureOr → Type
no setterinherited
deriveIterable → Type
no setterinherited
deriveList → Type
no setterinherited
deriveSet → Type
no setterinherited
deriveStream → Type
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
identity → String
final
isNullable → bool
no setterinherited
isQualified → bool

Available on TypeTree, provided by the QualifiedExtension extension

no setter
isSynthetic → bool

Available on TypeTree, provided by the QualifiedExtension extension

no setter
isTerminal → bool

Available on TypeTree<T>, provided by the TypeTreeExtension extension

no setter
nullable → TypeCapture
no setterinherited
qualified → TypeCapture

Available on TypeTree, provided by the QualifiedExtension extension

no setter
qualifiedOrBase → TypeCapture

Available on TypeTree, provided by the QualifiedExtension extension

no setter
qualifiedOrDynamic → TypeCapture

Available on TypeTree, provided by the QualifiedExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeArgument → Type
no setterinherited

Methods

castIterable(Iterable iterable) → Iterable
inherited
castList(List list) → List
inherited
castSet(Set set) → Set
inherited
consumeType<RETURN>(RETURN func<_>()) → RETURN
inherited
consumeTypeArg<RETURN, ARG>(RETURN func<_>(ARG), ARG arg) → RETURN
inherited
isAssignable(dynamic object) → bool
inherited
isAssignableToBase(dynamic obj) → bool

Available on TypeTree<T>, provided by the TypeTreeExtension extension

isBase<A>() → bool

Available on TypeTree<T>, provided by the TypeTreeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override