annotate abstract method
Annotates the given value and returns the result as an AnnotationResult.
Implementation
AnnotationResult annotate(T value, DogEngine engine);
Annotates the given value and returns the result as an AnnotationResult.
AnnotationResult annotate(T value, DogEngine engine);