An interface for things that can be converted to an AnnotationResult
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asAnnotationResult(
) → AnnotationResult - Converts this to an AnnotationResult.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator +(
AnnotationResultLike? other) → AnnotationResult - Combines this with another AnnotationResultLike.
-
operator ==(
Object other) → bool -
The equality operator.
inherited