MaterializedConverter class
A DogsMaterializer generated proxy around a DogConverter.
Constructors
- MaterializedConverter(DogEngine engineFork, DogConverter converter, NativeSerializerMode nativeMode, DogStructure structure, SchemaType originalSchema)
- A DogsMaterializer generated proxy around a DogConverter.
Properties
- converter → DogConverter
-
Underlying DogConverter used for serialization and deserialization.
final
- engineFork → DogEngine
-
DogEngine fork used to register the generated structures and converters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeMode → NativeSerializerMode
-
Resolved native serialization mode for the underlying converter.
final
- originalSchema → SchemaType
-
Original SchemaType used to generate this materialized converter.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structure → DogStructure
-
Underlying DogStructure used by the converter.
final
Methods
-
annotate(
dynamic value) → AnnotationResult - Proxy around ValidationMode.annotate.
-
fromJson(
String value) → dynamic - Proxy around jsonDecode before fromNative
-
fromNative(
dynamic value) → dynamic -
Proxy around
DogEngine.fromNative -
isValid(
dynamic value) → bool - Proxy around ValidationMode.validate.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
dynamic value) → String - Proxy around jsonEncode after toNative
-
toNative(
dynamic value) → dynamic -
Proxy around
DogEngine.toNative -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited