OperationModeRegistry class

The registry for OperationModes. Serves as the central point for resolving OperationModes for DogConverters and Types. Also functions as a cache for the resolved OperationModes.

Constructors

OperationModeRegistry()
Creates a new OperationModeRegistry and initializes the fast access fields. The cache is empty at this point and will be lazily populated.

Properties

hashCode int
The hash code for this object.
no setterinherited
nativeSerialization OperationModeCacheEntry<NativeSerializerMode>
Fast access to the entry for NativeSerializerMode.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validation OperationModeCacheEntry<ValidationMode>
Fast access to the entry for ValidationMode.
getter/setter pair

Methods

entry<T extends OperationMode>() OperationModeCacheEntry<T>
Returns the OperationModeCacheEntry for the given T.
getConverter<T extends OperationMode>(DogConverter converter, DogEngine engine) → T
Returns the OperationMode for the given converter and engine.
getType<T extends OperationMode>(Type type, DogEngine engine) → T
Returns the OperationMode for the given type and engine.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited