SchemaType class sealed
A schema type.
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nullable ↔ bool
-
Whether the type accepts null values.
getter/setter pair
-
properties
↔ Map<
String, dynamic> -
Additional properties of the schema.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ SchemaCoreType
-
The core type of the schema.
getter/setter pair
Methods
-
addButtonLabel(
String label) → SchemaType -
Available on SchemaType, provided by the BindingStyleSchemaBuilderExtension extension
-
clone(
) → SchemaType - Creates a deep copy of this schema type.
-
formHelper(
String helper) → SchemaType -
Available on SchemaType, provided by the BindingStyleSchemaBuilderExtension extension
-
formHint(
String hint) → SchemaType -
Available on SchemaType, provided by the BindingStyleSchemaBuilderExtension extension
-
formLabel(
String label) → SchemaType -
Available on SchemaType, provided by the BindingStyleSchemaBuilderExtension extension
-
formPrefix(
String prefix) → SchemaType -
Available on SchemaType, provided by the BindingStyleSchemaBuilderExtension extension
-
itemLabel(
String label) → SchemaType -
Available on SchemaType, provided by the BindingStyleSchemaBuilderExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts this schema type to a formatted JSON string.
-
toProperties(
) → Map< String, dynamic> - Converts this schema type to a map of json-schema-like properties.
-
toSha256(
) → String - Converts this schema type to a SHA-256 hash of its properties.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → dynamic - Gets a custom property from the schema.
-
operator []=(
String key, dynamic value) → void - Adds a custom property to the schema.
Static Properties
- any → SchemaType
-
Creates a schema type representing any value.
no setter
- boolean → SchemaType
-
Creates a schema type representing a boolean.
no setter
- integer → SchemaType
-
Creates a schema type representing an integer.
no setter
- none → SchemaType
-
Creates a schema type representing a null value.
no setter
- number → SchemaType
-
Creates a schema type representing a number.
no setter
- string → SchemaType
-
Creates a schema type representing a string.
no setter
Static Methods
-
array(
SchemaType items) → SchemaType - Creates a schema type representing an array of the given item type.
-
fromProperties(
Map< String, dynamic> properties) → SchemaType - Reads a SchemaType from a property map.
-
map(
SchemaType itemType) → SchemaType - Creates a schema type representing a string-keyed map with values of the given item type.
-
object(
{List< SchemaField> fields = const []}) → SchemaType - Creates a schema type representing an object with the given fields.
-
reference(
String serialName) → SchemaType - Creates a schema type representing a reference to another schema by its serial name.